! ###########################################################
!            Satellite Data Simulation Unit v2
!                     - MAINparameters -
!
! This module defines variables common to primary SDSU routines. 
!
!        Updated from MAINparameters.inc by H. M. (May 2009)
!
 Module MAINparameters
!
! Home directory
!
   character*(*), parameter :: homedir = '../../'
!
!  ######## microwave radiometer #######
!
! mxfreq : The number of channels (defined in 'param_set')
!                          
   integer :: mxfreq_microw
!
! freq  : Channel frequencies in [GHz] (defined in 'param_set')
!
   real, dimension(:), allocatable :: freq_microw
!
! inc_angle_mwr : viewing angle in [deg] (defined in 'param_set')
!
   real :: inc_angle_mwr
!
!  ############## radar ###############
!
! mxfreq_radar : The number of channels (defined in 'param_set')
!                          
   integer :: mxfreq_radar
!
! freq_radar : Channel frequencies in [GHz] (defined in 'param_set')
!
   real, dimension(:), allocatable :: freq_radar
!
! inc_angle_rdr : viewing angle in [deg] (defined in 'param_set')
!
   real :: inc_angle_rdr
!
!  ######## visible/IR imager ##########
!
! mxwavel : The number of channels (defined in 'param_set')
!                          
   integer :: mxwavel
!
! wavel      : Channel wavelengths in [micron]
! ngausp     : Number of Guassian quadrature points
!              (both defined in 'param_set')
!
   real,    dimension(:), allocatable :: wavel
   integer, dimension(:), allocatable :: ngausp
!
! znth_slr : solar zenith angle in [deg]
! znth_obs : veiwing zenith angle in [deg]
! azmth    : azimuth angle between the sun and sensor [deg]
! lab_endian : "ltl" or "big".
!           (all defined in 'param_set')
!
   real :: znth_slr,znth_obs,azmth
   character*3 :: lab_endian
!
! ###### input file list ######
!
! CRM file list
!
! nmodel : The number of input model (defined in 'def_file_list')
!
   integer :: nmodel
!
! CRM_file_list : Input file names (defined in 'def_file_list')
!
   character*90, dimension(:), allocatable :: CRM_file_list
!
! ########## running options ##########
!
! microw : microwave simulator switch; on (off) when .true. (.false.)
! radar  : radar simulator switch    ; on (off) when .true. (.false.)
! visIR  : visble/IR simulator switch; on (off) when .true. (.false.)
!           (all defined in 'param_set')
!
   logical :: microw, radar, visIR
!
! lut        : =.true. for using the Mie LUTs. Applicable to microwave
!                      radiometer and radar simulations.
! slant_path : =.true. for the slant-path option for microwave RT.
!                      (otherwise the plane-parallel option is selected.)
! meltp      : =.true. for implementing a simple melting particle scheme.
!                      Applicable to microwave radiometer and radar simulaions.
! beamconv   : =.true. for applying beam convolution online.
! background : "water", "land", or "mixed" to specify the surface condition
!              Use "sfc_type" to specify spatially variable surface type
!              when background="mixed". 
!           (all defined in 'param_set')
!
   logical :: lut, slant_path, meltp, beamconv
   character*5 :: background
!
! ######## cloud model variables #########
!
! ngridx, ngridy, nlyr : grid dimensions (defined in 'rd_CRM')
! deltax, deltay       : grid intervals  (defined in 'rd_CRM')
!
   integer :: ngridx, ngridy, nlyr
   real    :: deltax, deltay
!
! Input geophysical parameters
! See 'rd_CRM' for descriptions of individual variables.
!
   integer, dimension(:,:), allocatable :: ics,sfc_type
   real, dimension(:,:),    allocatable :: tskin,rainrate_sfc
   real, dimension(:,:),    allocatable :: wind_sfc,soilH2O
   real, dimension(:,:,:),  allocatable :: albd_visir
   real, dimension(:,:,:),  allocatable :: hght_lev,pres_lev,temp_lev
   real, dimension(:,:,:),  allocatable :: rlhm_avg
   real, dimension(:,:,:),  allocatable :: Wrain_avg,Wcldw_avg,Wcldi_avg
   real, dimension(:,:,:),  allocatable :: Wsnow_avg,Whail_avg,Wgrpl_avg
   real, dimension(:,:,:),  allocatable :: Nrain_avg,Nsnow_avg,Ngrpl_avg
   real, dimension(:,:,:),  allocatable :: Ncldw_avg,Ncldi_avg,Nhail_avg
!
!
! ########### output parameters #############
!
! microwave Tb
!
! Tb_out : Microwave brightness temperature in [K]
!   (  The last dimension (0:1) defines horizontal and vertical 
!      polarizations in this order. )
!
   real, dimension(:,:,:,:), allocatable ::  Tb_out
!
! radar Z and PIA
!
! dBZ_out : Radar reflectivity in [dBZ]
! PIA_out : Two-way path-integrated attenuation [dB]
!
   real, dimension(:,:,:,:), allocatable :: dBZ_out
   real, dimension(:,:,:),   allocatable :: PIA_out
!
! vis/IR radiance
!
! Ivir_out : radiance in [W/m2/str/micron] for visible and near-IR
!           wavelengths, and brightness temperature in [K]
!           when tbform = .true.
!  
   real, dimension(:,:,:), allocatable :: Ivir_out
   logical, dimension(:),  allocatable :: tbform
!
! ############## I/O paths ################
!
! CRMdir    : Input CRM directory 
! outputdir : Output directory 
! lutdir    : Directory path for the Mie LUTs
!
   character*(*), parameter :: outputdir = homedir//'outputs/'
   character*(*), parameter :: CRMdir = homedir//'CRM/'
   Character*(*), parameter :: lutdir = homedir//'Mie-table/'
!
 end Module MAINparameters
