! ############################################################
!            Satellite Data Simulation Unit v2
!                     -  param_set -
!
! User-defined parameters are set up in this subroutine.
!
!                 Updated from param_set.f by H. M. (May, 2009)
!
 Subroutine param_set
   Use MAINparameters
   Implicit NONE
!
! 1. Microwave radiometer -------------------------------------------
!
! 1.1 Microwave-radiometer simulation is skipped when microw = .false.
!
   microw = .true.
!
! 1.2 Number of channels and channel frequencies [GHz]
!
   mxfreq_microw = 5    ; allocate ( freq_microw(mxfreq_microw) )
   freq_microw(1) = 10.7
   freq_microw(2) = 19.35
   freq_microw(3) = 21.3
   freq_microw(4) = 37.0 
   freq_microw(5) = 85.5
!
! 1.3 Viewing zenith angle [deg]
!
   inc_angle_mwr = 52.8
!
! 1.4 "slanth path" option (.true. or .false.)
!    The satellite-viewing path is assumed to intersect neighboring
!    culumns when true. The independent pixel approximation is applied 
!    when false.
!
   slant_path = .false.
!
! 2. Radar ---------------------------------------------------------
!
! 2.1 Radar simulation is skipped when radar = .false.
!
   radar = .true.
!
! 2.2 Number of channels and channel frequencies [GHz]
!
   mxfreq_radar = 2    ; allocate ( freq_radar(mxfreq_radar) )
   freq_radar(1) = 13.6
   freq_radar(2) = 35.5
!
! 2.3 Viewing zenith angle [deg]
!
   inc_angle_rdr = 0.
!
! 3. Visible and IR radiometer -------------------------------------
!
! 3.1 Visble/IR radiometer simulation is skipped when visIR = .false.
!     
   visIR = .true.
!
! 3.2 Number of channels and channel wavelengths [micron]
!     The computed radiance will be in [W/m2/str/micron] when
!     tbform = .false., and otherwise converted to brightness
!     temperature in [K].
!
   mxwavel = 5    ; allocate ( wavel(mxwavel), tbform(mxwavel) )
   wavel(1) = 0.62  ; tbform(1) = .false.
   wavel(2) = 1.6   ; tbform(2) = .false.
   wavel(3) = 3.8   ; tbform(3) = .false.
   wavel(4) = 10.8  ; tbform(4) = .true.
   wavel(5) = 12.0  ; tbform(5) = .true.
!
! 3.3 Solar and viewing zenith angles [deg]
!     (nighttime when znth_slr < 0.)
!     (znth_obs = 0. for nadir viewing)
!
   znth_slr = 30.
   znth_obs = 0.
!
! 3.4 Azimuthal angle between the sun and sensor [deg]
!
   azmth    = 0.
!
! 3.5 Number of Gaussian quadrature points used for discrete-ordinate 
!     radiative transfer calculations (e.g., 2-stream approximation 
!     when ngausp = 1). Recommended to be 6 or higher for shortwave and
!     to be 2 or higher for longwave calculations. Calculations can
!     be sped up by giving a smaller number here at the expense of a loss
!     of accuracy.
!
   allocate ( ngausp(mxwavel) )
   ngausp(1) = 6
   ngausp(2) = 6
   ngausp(3) = 6
   ngausp(4) = 2
   ngausp(5) = 2
!
! 3.7 Specify 'ltl' for little endian or 'big' for big endian
!     according to your machine spec. This label is for use by
!     the k-distribution database.
!
   lab_endian = 'ltl'    !! for little endian CPU
!   lab_endian = 'big'    !! for big endian CPU
!
! 4. General options for radiative transfer calculations
!
! 4.1 Surface background ('water', 'land', or 'mixed')
!     Applicable for microwave and visible/IR radiometer simulations.
!     The surface emissivity is computed for a water background when
!     background='water'. A Lambert surface is assumed when 'land'.
!     Set backgrond='mixed' when surface type varies spatially.
!     'sfc_type' (defined in 'rd_CRM.f90') specifies local surface type 
!     when background='mixed' (effective for v2.0.01 or later).
!
   background = 'water'
!
! 4.2 Mie lookup table (LUT) (.true. or .false.)
!     Mie LUT files must be created in advance when lut=.true. 
!     The LUT generating program is found in 'src/MieLUT/'.
!
   lut = .true.
!
! 4.3 Melting particle characterization (.true. or .false.)
!     A simple melting-particle scheme is implemented when meltp=.true. 
!     If applied, snow and rain water are replaced by melting particles 
!     for a layer below the 0 C height. See the User's Guide for details. 
!     Applicable to the microwave radiometer and radar simulators.
!
   meltp = .true.
!
! 4.4 Beam convolution with specified FOV sizes (.true. or .false.)
!     Calculated "measurements" are smoothed over a field of view
!     (FOV) with a Gaussian beam pattern and are output into an
!     additional file (*.fov.bin) when beamconv=.true. The FOV sizes
!     are defined in '/src/beamconv/param_set_bmcv.f90'. Alternatively,
!     the beam convolution may be applied off-line by separate routines
!     in 'src/beamconv/'.
!
   beamconv = .true.
!
   Return
 End Subroutine param_set
